@@ -5,6 +5,85 @@ import matplotlib.pyplot as plt
 import seaborn as sns
 
 
+def get_bar_x(ax):
+    """Get bar centers."""
+    x = np.array(sorted([p.get_x() + (p.get_width() / 2) for p in ax.patches]))
+    return x
+
+
+def get_point_max_y(ax):
+    """Get highest point in each bin."""
+    collections = [c for c in ax.collections if c.get_offsets().shape[0] > 1]
+    y = np.array([np.nanmax(c.get_offsets()[:, 1]) for c in collections])
+    x = np.array([np.nanmean(c.get_offsets()[:, 0]) for c in collections])
+    y = y[np.argsort(x)]
+    return y
+
+
+def add_swarm_bar_sig(ax, sig_ind, y_offset=None):
+    """Add significance stats to swarm bar plot."""
+    # center of each bar in left/right order
+    bx = get_bar_x(ax)
+
+    # highest point in each point plot in left/right order
+    cy = get_point_max_y(ax)
+
+    # define y point relative to the highest point
+    if y_offset is None:
+        y_lim = ax.get_ylim()
+        y_offset = (y_lim[1] - y_lim[0]) * .1
+
+    # plot significance markers
+    ax.plot(
+        bx[sig_ind],
+        cy[sig_ind] + y_offset,
+        markersize=8,
+        color='k',
+        linestyle='',
+        marker=(5, 2, 0),
+    )
+
+
+def plot_sig(x, y, spacing, line_kws={}, marker_kws={}, ax=None):
+    """Plot brackets with a significance indicator."""
+    if ax is None:
+        ax = plt.gca()
+
+    # bar centers
+    x1, x2 = x
+
+    # largest y-values
+    y1, y2 = y
+
+    # line and annotation y-values
+    yl1 = max(y1, y2) + spacing
+    yl2 = yl1 + spacing * .8
+    yl3 = yl2 + spacing
+
+    # brackets connecting bars
+    line_prop = {'linewidth': 0.75, 'color': 'k'}
+    line_prop.update(line_kws)
+    ax.plot([x1, x1, x2, x2], [yl1, yl2, yl2, yl1], **line_prop)
+
+    # significance marker
+    marker_prop = {'marker': (5, 2, 0), 'markersize': 8, 'color': 'k'}
+    marker_prop.update(marker_kws)
+    ax.plot((x1 + x2) / 2, yl3, **marker_prop)
+
+
+def add_swarm_bar_sig_diff(ax, sig_ind_pairs, y_offset=None, **kwargs):
+    """Add significant comparison markers to swarm bar plot."""
+    bx = get_bar_x(ax)
+    cy = get_point_max_y(ax)
+
+    if y_offset is None:
+        y_lim = ax.get_ylim()
+        y_offset = (y_lim[1] - y_lim[0]) * .05
+
+    for ind in sig_ind_pairs:
+        plot_sig(bx[ind], cy[ind], y_offset, ax=ax, **kwargs)
+
+
 def plot_swarm_bar(
     data=None,
     x=None,
@@ -16,9 +95,12 @@ def plot_swarm_bar(
     point_kind='swarm',
     legend=True,
     width=None,
+    sig_ind=None,
+    sig_diff_ind=None,
     ax=None,
     point_kws={},
     bar_kws={},
+    **kwargs,
 ):
     """
     Make a bar plot with individual points and error bars.
@@ -56,6 +138,13 @@ def plot_swarm_bar(
     width : float, optional
         Width of the bars.
 
+    sig_ind : list of int, optional
+        Indices of bars (from left to right) to label as significant.
+
+    sig_diff_ind : list of list of int, optional
+        A list of pairs (given as indices of bars from left to right)
+        to mark as significant comparisons.
+
     ax : matplotlib.axes.Axes, optional
         Axes object to draw the plot onto; if not specified, will use
         the current Axes.
@@ -94,9 +183,9 @@ def plot_swarm_bar(
     }
     point_prop.update(point_kws)
     if point_kind == 'swarm':
-        sns.swarmplot(data=data, x=x, y=y, hue=hue, ax=ax, **point_prop)
+        sns.swarmplot(data=data, x=x, y=y, hue=hue, ax=ax, **point_prop, **kwargs)
     elif point_kind == 'strip':
-        sns.stripplot(data=data, x=x, y=y, hue=hue, ax=ax, **point_prop)
+        sns.stripplot(data=data, x=x, y=y, hue=hue, ax=ax, **point_prop, **kwargs)
     else:
         raise ValueError(f'Invalid point plot kind: {point_kind}')
 
@@ -112,14 +201,14 @@ def plot_swarm_bar(
         'palette': light,
     }
     bar_prop.update(bar_kws)
-    sns.barplot(data=data, x=x, y=y, hue=hue, ax=ax, **bar_prop)
+    sns.barplot(data=data, x=x, y=y, hue=hue, ax=ax, **bar_prop, **kwargs)
 
     # remove overall xlabel and increase size of x-tick labels
     ax.set_xlabel('')
     ax.tick_params(axis='x', labelsize='large')
 
     # fix ordering of plot elements
-    plt.setp(ax.lines, zorder=100, linewidth=1.25, label=None)
+    plt.setp(ax.lines, zorder=100, linewidth=1.25, label=None, clip_on=False)
     plt.setp(ax.collections, zorder=100, label=None)
 
     # modify the width of the bar plot
@@ -147,31 +236,10 @@ def plot_swarm_bar(
         if hue is not None and legend:
             # refresh the legend to remove the swarm points
             ax.legend()
+
+    # add significance markers
+    if sig_ind is not None:
+        add_swarm_bar_sig(ax, sig_ind)
+    if sig_diff_ind is not None:
+        add_swarm_bar_sig_diff(ax, sig_diff_ind)
     return ax
-
-
-def plot_sig(x, y, spacing, line_kws={}, marker_kws={}, ax=None):
-    """Plot brackets with a significance indicator."""
-    if ax is None:
-        ax = plt.gca()
-
-    # bar centers
-    x1, x2 = x
-
-    # largest y-values
-    y1, y2 = y
-
-    # line and annotation y-values
-    yl1 = max(y1, y2) + spacing
-    yl2 = yl1 + spacing
-    yl3 = yl2 + spacing
-
-    # brackets connecting bars
-    line_prop = {'linewidth': 0.75, 'color': 'k'}
-    line_prop.update(line_kws)
-    ax.plot([x1, x1, x2, x2], [yl1, yl2, yl2, yl1], **line_prop)
-
-    # significance marker
-    marker_prop = {'marker': (5, 2, 0), 'markersize': 8, 'color': 'k'}
-    marker_prop.update(marker_kws)
-    ax.plot((x1 + x2) / 2, yl3, **marker_prop)
